#!/usr/bin/env python3
from flask import Flask, render_template_string, request,jsonify
from werkzeug.utils import secure_filename
import os

INDEX_HTML = '''
<!DOCTYPE html>
<html lang="en"><head>
<meta http-equiv="content-type" content="text/html; charset=UTF-8">
<meta charset="utf-8">
<title>Drag and Drop File Uploading</title>
<!-- <link rel="canonical" href="https://css-tricks.com/examples/DragAndDropFileUploading/"> -->
<meta name="viewport" content="width=device-width,initial-scale=1">

<style>


/*
    AUTHOR: Osvaldas Valutis, www.osvaldas.info
*/

body,
.ad,
.sm
{
    font-family: Lucida Grande, Helvetica Neue, Helvetica, Arial, Verdana, sans-serif;
}

a
{
    color: currentColor;
    text-decoration: none;
}

.clearfix::after
{
    content: '';
    display: table;
    clear: both;
}



/*
    AD
*/

.ad
{
    width: 9.375rem; /* 150 */
    color: #444;
    color: rgba( 0, 0, 0, .75 );
    background-color: #fff;
    background-color: rgba( 255, 255, 255, .5 );
    position: fixed;
    z-index: 1000;
    top: 0.625rem; /* 10 */
    left: 0.625rem; /* 10 */
    padding: 0.5rem 0.625rem; /* 8 10 */
}
.ad--dark
{
    color: #ddd;
    color: rgba( 255, 255, 255, .75 );
    background-color: #111;
    background-color: rgba( 0, 0, 0, .5 );
}
    .ad__close
    {
        width: 0.625rem; /* 10 */
        height: 0.625rem; /* 10 */
        background-color: #777;
        background-color: rgba( 0, 0, 0, .5 );
        border-radius: 50%;
        position: absolute;
        z-index: 1;
        top: -0.25rem; /* 4 */
        right: -0.25rem; /* 4 */

        -webkit-transition: -webkit-transform .25s ease-in-out;
        transition: transform .25s ease-in-out;
    }
    .ad--dark .ad__close
    {
        background-color: #ddd;
        background-color: rgba( 255, 255, 255, .75 );

    }
    .ad__close:hover,
    .ad__close:focus
    {
        -webkit-transform: scale( 1.25 );
        -ms-transform: scale( 1.25 );
        transform: scale( 1.25 );
    }

    #carbonads
    {
        font-size: 0.875rem; /* 14 */
        letter-spacing: -0.071em; /* 1 (14) */
        line-height: 1.125rem; /* 18 */
    }
        #carbonads a
        {
            color: currentColor;
            display: block;
            margin-top: 0.313rem; /* 5 */
        }
        #carbonads .carbon-poweredby
        {
            font-size: 0.75rem; /* 12 */
            text-transform: uppercase;
            color: #aaa;
            color: rgba( 0, 0, 0, .25 );
        }
        .ad--dark #carbonads .carbon-poweredby
        {
            color: #999;
            color: rgba( 255, 255, 255, .25 );
        }



/*
    SOCIAL MEDIA
*/

.sm
{
    width: 100%;
    height: 2.5rem; /* 40 */
    color: #444;
    color: rgba( 0, 0, 0, .75 );
    background-color: #fff;
    background-color: rgba( 255, 255, 255, .5 );
    overflow: hidden;
    position: fixed;
    z-index: 1001;
    bottom: 0;
    left: 0;
    padding: 0.625rem 1.25rem 0; /* 10 20 */
}
    .sm--dark
    {
        color: #ddd;
        color: rgba( 255, 255, 255, .75 );
        background-color: #111;
        background-color: rgba( 0, 0, 0, .5 );
    }
    .sm ul
    {
    }
        .sm li
        {
            float: right;
            margin-left: 1rem;
        }
        .sm li:first-child
        {
            float: left;
            margin-left: 0;
        }
            .sm .googleplus-one
            {
                max-width: 60px;
            }
            .sm .twitter-follow > *:not( :first-child ),
            .sm .twitter-share > *:not( :first-child )
            {
                display: none;
            }

        @media screen{ @media ( min-width: 0px ) /* everything but Internet Explorer and Safari ≤6 */
        {
            .sm li:last-child
            {
                opacity: 0;
                -webkit-transition: opacity .25s ease-in-out;
                transition: opacity .25s ease-in-out;
            }
            .sm:hover li:last-child
            {
                opacity: 1;
            }   
        }}

            .sm__back
            {
                font-size: 0.875rem; /* 14 */
                font-weight: bold;
                color: currentColor;
                text-transform: uppercase;
                position: relative;
            }
                .sm__back::before
                {
                    width: 0;
                    height: 0;
                    border: 0.313rem solid transparent; /* 5 */
                    border-left: none;
                    border-right-color: currentColor;
                    content: '';
                    display: inline-block;
                    position: relative;
                    left: 0;
                    margin-right: 0.313rem; /* 5 */

                    -webkit-transition: left .25s ease-in-out;
                    transition: left .25s ease-in-out;
                }
                .sm__back:hover::before,
                .sm__back:focus::before
                {
                    left: -0.313rem; /* 5 */
                }



/*
    RESPONSIVENESS
*/

@media screen and (max-width: 40em), screen and (max-height: 40em) /* 640 */
{
    .ad,
    .sm
    {
        display: none;
    }
}


        html
        {
        }
            body
            {
                font-family: Roboto, sans-serif;
                color: #0f3c4b;
                background-color: #e5edf1;
                padding: 5rem 1.25rem; /* 80 20 */
            }

            .container
            {
                width: 100%;
                max-width: 680px; /* 800 */
                text-align: center;
                margin: 0 auto;
            }

                .container h1
                {
                    font-size: 42px;
                    font-weight: 300;
                    color: #0f3c4b;
                    margin-bottom: 40px;
                }
                .container h1 a:hover,
                .container h1 a:focus
                {
                    color: #39bfd3;
                }

                .container nav
                {
                    margin-bottom: 40px;
                }
                    .container nav a
                    {
                        border-bottom: 2px solid #c8dadf;
                        display: inline-block;
                        padding: 4px 8px;
                        margin: 0 5px;
                    }
                    .container nav a.is-selected
                    {
                        font-weight: 700;
                        color: #39bfd3;
                        border-bottom-color: currentColor;
                    }
                    .container nav a:not( .is-selected ):hover,
                    .container nav a:not( .is-selected ):focus
                    {
                        border-bottom-color: #0f3c4b;
                    }

                .container footer
                {
                    color: #92b0b3;
                    margin-top: 40px;
                }
                    .container footer p + p
                    {
                        margin-top: 1em;
                    }
                    .container footer a:hover,
                    .container footer a:focus
                    {
                        color: #39bfd3;
                    }

                .box
                {
                    font-size: 1.25rem; /* 20 */
                    background-color: #c8dadf;
                    position: relative;
                    padding: 100px 20px;
                }
                .box.has-advanced-upload
                {
                    outline: 2px dashed #92b0b3;
                    outline-offset: -10px;

                    -webkit-transition: outline-offset .15s ease-in-out, background-color .15s linear;
                    transition: outline-offset .15s ease-in-out, background-color .15s linear;
                }
                .box.is-dragover
                {
                    outline-offset: -20px;
                    outline-color: #c8dadf;
                    background-color: #fff;
                }
                    .box__dragndrop,
                    .box__icon
                    {
                        display: none;
                    }
                    .box.has-advanced-upload .box__dragndrop
                    {
                        display: inline;
                    }
                    .box.has-advanced-upload .box__icon
                    {
                        width: 100%;
                        height: 80px;
                        fill: #92b0b3;
                        display: block;
                        margin-bottom: 40px;
                    }

                    .box.is-uploading .box__input,
                    .box.is-success .box__input,
                    .box.is-error .box__input
                    {
                        visibility: hidden;
                    }

                    .box__uploading,
                    .box__success,
                    .box__error
                    {
                        display: none;
                    }
                    .box.is-uploading .box__uploading,
                    .box.is-success .box__success,
                    .box.is-error .box__error
                    {
                        display: block;
                        position: absolute;
                        top: 50%;
                        right: 0;
                        left: 0;

                        -webkit-transform: translateY( -50% );
                        transform: translateY( -50% );
                    }
                    .box__uploading
                    {
                        font-style: italic;
                    }
                    .box__success
                    {
                        -webkit-animation: appear-from-inside .25s ease-in-out;
                        animation: appear-from-inside .25s ease-in-out;
                    }
                        @-webkit-keyframes appear-from-inside
                        {
                            from    { -webkit-transform: translateY( -50% ) scale( 0 ); }
                            75%     { -webkit-transform: translateY( -50% ) scale( 1.1 ); }
                            to      { -webkit-transform: translateY( -50% ) scale( 1 ); }
                        }
                        @keyframes appear-from-inside
                        {
                            from    { transform: translateY( -50% ) scale( 0 ); }
                            75%     { transform: translateY( -50% ) scale( 1.1 ); }
                            to      { transform: translateY( -50% ) scale( 1 ); }
                        }

                    .box__restart
                    {
                        font-weight: 700;
                    }
                    .box__restart:focus,
                    .box__restart:hover
                    {
                        color: #39bfd3;
                    }

                    .js .box__file
                    {
                        width: 0.1px;
                        height: 0.1px;
                        opacity: 0;
                        overflow: hidden;
                        position: absolute;
                        z-index: -1;
                    }
                    .js .box__file + label
                    {
                        max-width: 80%;
                        text-overflow: ellipsis;
                        white-space: nowrap;
                        cursor: pointer;
                        display: inline-block;
                        overflow: hidden;
                    }
                    .js .box__file + label:hover strong,
                    .box__file:focus + label strong,
                    .box__file.has-focus + label strong
                    {
                        color: #39bfd3;
                    }
                    .js .box__file:focus + label,
                    .js .box__file.has-focus + label
                    {
                        outline: 1px dotted #000;
                        outline: -webkit-focus-ring-color auto 5px;
                    }
                        .js .box__file + label *
                        {
                            /* pointer-events: none; */ /* in case of FastClick lib use */
                        }

                    .no-js .box__file + label
                    {
                        display: none;
                    }

                    .no-js .box__button
                    {
                        display: block;
                    }
                    .box__button
                    {
                        font-weight: 700;
                        color: #e5edf1;
                        background-color: #39bfd3;
                        display: block;
                        padding: 8px 16px;
                        margin: 40px auto 0;
                    }
                        .box__button:hover,
                        .box__button:focus
                        {
                            background-color: #0f3c4b;
                        }

    </style>

<script>(function(e,t,n){var r=e.querySelectorAll("html")[0];r.className=r.className.replace(/(^|\s)no-js(\s|$)/,"$1js$2")})(document,window,0);</script>
</head>
<body>
<div class="container" role="main">

<nav role="navigation">
<!-- <a href="https://css-tricks.com/examples/DragAndDropFileUploading/">Auto Submit</a> -->
<!-- <a href="https://css-tricks.com/examples/DragAndDropFileUploading/?submit-on-demand" class="is-selected">Submit On Demand</a> -->
</nav>
<form method="post" action="/upload" enctype="multipart/form-data" novalidate="" class="box has-advanced-upload">
<div class="box__input">
<svg class="box__icon" xmlns="http://www.w3.org/2000/svg" width="50" height="43" viewBox="0 0 50 43"><path d="M48.4 26.5c-.9 0-1.7.7-1.7 1.7v11.6h-43.3v-11.6c0-.9-.7-1.7-1.7-1.7s-1.7.7-1.7 1.7v13.2c0 .9.7 1.7 1.7 1.7h46.7c.9 0 1.7-.7 1.7-1.7v-13.2c0-1-.7-1.7-1.7-1.7zm-24.5 6.1c.3.3.8.5 1.2.5.4 0 .9-.2 1.2-.5l10-11.6c.7-.7.7-1.7 0-2.4s-1.7-.7-2.4 0l-7.1 8.3v-25.3c0-.9-.7-1.7-1.7-1.7s-1.7.7-1.7 1.7v25.3l-7.1-8.3c-.7-.7-1.7-.7-2.4 0s-.7 1.7 0 2.4l10 11.6z"></path></svg>
<!-- <input type="file" name="files[]" id="file" class="box__file" data-multiple-caption="{count} files selected" multiple=""> -->
<input type="file" name="files[]" id="file" class="box__file" data-multiple-caption="{count} files selected">
<label for="file"><strong>Choose a file</strong><span class="box__dragndrop"> or drag it here</span>.</label>
<button type="submit" class="box__button">Upload</button>
</div>
<div class="box__uploading">Uploading…</div>
<div class="box__success">Done! <a href="/" class="box__restart" role="button">Upload more?</a></div>
<div class="box__error">Error! <span></span>. <a href="." class="box__restart" role="button">Try again!</a></div>
<!-- <input type="hidden" name="ajax" value="1"></form> -->

</div>



<script>

    /**
    The purpose of "use strict" is to indicate that the code should be executed in "strict mode".

    With strict mode, you can not, for example, use undeclared variables.

    **/
    //'use strict'; // lol 

    ;( function ( document, window, index )
    {
        // feature detection for drag&drop upload
        var isAdvancedUpload = function checkAdvancedUpload ()
            {
                var div = document.createElement( 'div' );
                return ( ( 'draggable' in div ) || ( 'ondragstart' in div && 'ondrop' in div ) ) && 'FormData' in window && 'FileReader' in window;
            }();


        // applying the effect for every form
        var forms = document.querySelectorAll( '.box' );
        Array.prototype.forEach.call( forms, function( form )
        {
            var input        = form.querySelector( 'input[type="file"]' ),
                label        = form.querySelector( 'label' ),
                errorMsg     = form.querySelector( '.box__error span' ),
                restart      = form.querySelectorAll( '.box__restart' ),
                droppedFiles = false,
                showFiles    = function( files )
                {
                    label.textContent = files.length > 1 ? ( input.getAttribute( 'data-multiple-caption' ) || '' ).replace( '{count}', files.length ) : files[ 0 ].name;
                },
                triggerFormSubmit = function()
                {
                    var event = document.createEvent( 'HTMLEvents' );
                    event.initEvent( 'submit', true, false );
                    form.dispatchEvent( event );
                };

            // letting the server side to know we are going to make an Ajax request
            // var ajaxFlag = document.createElement( 'input' );
            // ajaxFlag.setAttribute( 'type', 'hidden' );
            // ajaxFlag.setAttribute( 'name', 'ajax' );
            // ajaxFlag.setAttribute( 'value', 1 );
            // form.appendChild( ajaxFlag );

            // automatically submit the form on file select
            input.addEventListener( 'change', function( e )
            {
                showFiles( e.target.files );

                
            });

            // drag&drop files if the feature is available
            if( isAdvancedUpload )
            {
                form.classList.add( 'has-advanced-upload' ); // letting the CSS part to know drag&drop is supported by the browser

                [ 'drag', 'dragstart', 'dragend', 'dragover', 'dragenter', 'dragleave', 'drop' ].forEach( function( event )
                {
                    form.addEventListener( event, function( e )
                    {
                        // preventing the unwanted behaviours
                        e.preventDefault();
                        e.stopPropagation();
                    });
                });
                [ 'dragover', 'dragenter' ].forEach( function( event )
                {
                    form.addEventListener( event, function()
                    {
                        form.classList.add( 'is-dragover' );
                    });
                });
                [ 'dragleave', 'dragend', 'drop' ].forEach( function( event )
                {
                    form.addEventListener( event, function()
                    {
                        form.classList.remove( 'is-dragover' );
                    });
                });
                form.addEventListener( 'drop', function( e )
                {
                    droppedFiles = e.dataTransfer.files; // the files that were dropped
                    showFiles( droppedFiles );

                                    });
            }


            // if the form was submitted
            form.addEventListener( 'submit', function submitForm( e )
            {
                // preventing the duplicate submissions if the current one is in progress
                if( form.classList.contains( 'is-uploading' ) ) return false;

                form.classList.add( 'is-uploading' );
                form.classList.remove( 'is-error' );

                if( isAdvancedUpload ) // ajax file upload for modern browsers
                {
                    e.preventDefault();

                    // gathering the form data
                    var ajaxData = new FormData( form );
                    if( droppedFiles )
                    {
                        Array.prototype.forEach.call( droppedFiles, function( file )
                        {
                            ajaxData.append( input.getAttribute( 'name' ), file );
                        });
                    }

                    // ajax request
                    var ajax = new XMLHttpRequest();
                    ajax.open( form.getAttribute( 'method' ), form.getAttribute( 'action' ), true );

                    ajax.onload = function()
                    {
                        form.classList.remove( 'is-uploading' );
                        if( ajax.status >= 200 && ajax.status < 400 )
                        {
                            alert( ajax.responseText );
                            var data = JSON.parse( ajax.responseText );
                            form.classList.add( data.success == true ? 'is-success' : 'is-error' );
                            if( !data.success ) { 
                                errorMsg.textContent = data.error;
                            }

                            
                        }
                        else alert( 'Error. Please, contact the webmaster!' );
                    };

                    ajax.onerror = function()
                    {
                        form.classList.remove( 'is-uploading' );
                        alert( 'Error. Please, try again!' );
                    };

                    ajax.send( ajaxData );
                }
                else // fallback Ajax solution upload for older browsers
                {
                    var iframeName  = 'uploadiframe' + new Date().getTime(),
                        iframe      = document.createElement( 'iframe' );

                        $iframe     = $( '<iframe name="' + iframeName + '" style="display: none;"></iframe>' );

                    iframe.setAttribute( 'name', iframeName );
                    iframe.style.display = 'none';

                    document.body.appendChild( iframe );
                    form.setAttribute( 'target', iframeName );

                    iframe.addEventListener( 'load', function()
                    {
                        var data = JSON.parse( iframe.contentDocument.body.innerHTML );
                        form.classList.remove( 'is-uploading' )
                        form.classList.add( data.success == true ? 'is-success' : 'is-error' )
                        form.removeAttribute( 'target' );
                        if( !data.success ) errorMsg.textContent = data.error;
                        iframe.parentNode.removeChild( iframe );
                    });
                }
            });


            // restart the form if has a state of error/success
            Array.prototype.forEach.call( restart, function( entry )
            {
                entry.addEventListener( 'click', function( e )
                {
                    e.preventDefault();
                    form.classList.remove( 'is-error', 'is-success' );
                    input.click();
                });
            });

            // Firefox focus bug fix for file input
            input.addEventListener( 'focus', function(){ input.classList.add( 'has-focus' ); });
            input.addEventListener( 'blur', function(){ input.classList.remove( 'has-focus' ); });

        });
    }( document, window, 0 ));

</script>

</body></html>
'''


# script_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'templates')

app = Flask(__name__)
            # ,
            # static_url_path='',
            # static_folder=os.path.join(script_dir, 'templates'),
            # template_folder=os.path.join(script_dir, 'templates'))

UPLOADPATH = os.path.join(os.getcwd(), "uploads")
if not os.path.exists(UPLOADPATH):
    print("making dir", UPLOADPATH, "since it didn't exist")
    os.mkdir(UPLOADPATH)

@app.route('/')
def index():
   return render_template_string(INDEX_HTML)
    
@app.route('/upload', methods = ['GET', 'POST'])
def upload_file():
    if request.method == 'POST':
        import pprint
        pprint.pprint(request.files)

        # files = request.files
        # import code
        # code.interact(local=locals())

        for f in request.files.getlist('files[]'):
            if f.filename == "":
                continue
            if "app.py" not in f.filename:
                print('secure filename: ', secure_filename(f.filename))
                f.save(os.path.join(UPLOADPATH, secure_filename(f.filename)))
            else:
                print("bad file name", f.filename)
                return jsonify({"message":"illegal filename", "success":0})
        return jsonify({'message':'file uploaded successfully', 'success':1})
        
if __name__ == '__main__':
    print("upload directory at", UPLOADPATH)
    app.run(debug = False, host='0.0.0.0', port=5100)